@@ -186,6 +186,20 @@ typedef enum {
   WEBKIT_SNAPSHOT_REGION_FULL_DOCUMENT,
 } WebKitSnapshotRegion;
 
+/**
+ * WebKitWebProcessTerminationReason:
+ * @WEBKIT_WEB_PROCESS_CRASHED: the web process crashed.
+ * @WEBKIT_WEB_PROCESS_EXCEEDED_MEMORY_LIMIT: the web process exceeded the memory limit.
+ *
+ * Enum values used to specify the reason why the web process terminated abnormally.
+ *
+ * Since: 2.20
+ */
+typedef enum {
+    WEBKIT_WEB_PROCESS_CRASHED,
+    WEBKIT_WEB_PROCESS_EXCEEDED_MEMORY_LIMIT
+} WebKitWebProcessTerminationReason;
+
 struct _WebKitWebView {
     WebKitWebViewBase parent;
 
@@ -253,10 +267,11 @@ struct _WebKitWebViewClass {
     gboolean   (* show_option_menu)            (WebKitWebView               *web_view,
                                                 GdkRectangle                *rectangle,
                                                 WebKitOptionMenu            *menu);
+    void       (* web_process_terminated)      (WebKitWebView               *web_view,
+                                                WebKitWebProcessTerminationReason reason);
 
     void (*_webkit_reserved0) (void);
     void (*_webkit_reserved1) (void);
-    void (*_webkit_reserved2) (void);
 };
 
 WEBKIT_API GType
@@ -415,7 +430,7 @@ webkit_web_view_execute_editing_command_with_argument(WebKitWebView
 WEBKIT_API WebKitFindController *
 webkit_web_view_get_find_controller                  (WebKitWebView             *web_view);
 
-WEBKIT_API JSGlobalContextRef
+WEBKIT_DEPRECATED JSGlobalContextRef
 webkit_web_view_get_javascript_global_context        (WebKitWebView             *web_view);
 
 WEBKIT_API void
@@ -429,6 +444,18 @@ webkit_web_view_run_javascript_finish                (WebKitWebView
                                                       GAsyncResult              *result,
                                                       GError                   **error);
 
+WEBKIT_API void
+webkit_web_view_run_javascript_in_world              (WebKitWebView             *web_view,
+                                                      const gchar               *script,
+                                                      const gchar               *world_name,
+                                                      GCancellable              *cancellable,
+                                                      GAsyncReadyCallback        callback,
+                                                      gpointer                   user_data);
+WEBKIT_API WebKitJavascriptResult *
+webkit_web_view_run_javascript_in_world_finish       (WebKitWebView             *web_view,
+                                                      GAsyncResult              *result,
+                                                      GError                   **error);
+
 WEBKIT_API void
 webkit_web_view_run_javascript_from_gresource        (WebKitWebView             *web_view,
                                                       const gchar               *resource,
